@@ -8,25 +8,26 @@ use Pod::Usage;
 use strict;
 use warnings;
 
-my $VERSION = '5.53';
+my $VERSION = '5.54';
 my $GDV = "GD_Juggle_Codons_$VERSION";
 my $GDS = "_CJ";
 
 my %ALGNAME = (most_different_sequence => 1, balanced => 1,
   random => 1, high => 1, least_different_RSCU => 1);
-  
+
 local $| = 1;
 
 ##Get Arguments
 my %p = ();
 GetOptions (
-      'input=s'     => \$p{INPUT},
-      'output=s'    => \$p{OUTPUT},
-      'format=s'    => \$p{FORMAT},
-      'rscu=s'      => \$p{FILES},
-      'organism=s'  => \$p{ORGS},
-      'algorithm=s' => \$p{ALGS},
+      'input:s'     => \$p{INPUT},
+      'output:s'    => \$p{OUTPUT},
+      'format:s'    => \$p{FORMAT},
+      'rscu:s'      => \$p{FILES},
+      'organism:s'  => \$p{ORGS},
+      'algorithm:s' => \$p{ALGS},
       'split'       => \$p{SPLIT},
+      'string:s'    => \$p{STRING},
       'help'        => \$p{HELP}
 );
 
@@ -39,15 +40,28 @@ pod2usage(-verbose=>99, -sections=>"NAME|VERSION|DESCRIPTION|ARGUMENTS|USAGE")
 my $GD = Bio::GeneDesign->new();
 
 #The input file must exist and be a format we care to read.
-die "\n GDERROR: You must supply an input file.\n"
-  if (! $p{INPUT});
-my ($iterator, $filename, $suffix) = $GD->import_seqs($p{INPUT});
+die "\n GDERROR: You must supply an input.\n"
+  if (! $p{INPUT} && ! $p{STRING});
+  
+die "\n GDERROR: Either a file or a string input, please.\n"
+  if ($p{INPUT} && $p{STRING});
+  
+my ($iterator, $filename, $suffix) = (undef, undef, undef);
 
-$p{FORMAT} = $p{FORMAT} || $suffix || "genbank";
+if ($p{INPUT})
+{
+  ($iterator, $filename, $suffix) = $GD->import_seqs($p{INPUT});
+}
+elsif ($p{STRING})
+{
+  ($iterator, $filename, $suffix) = $GD->import_seq_from_string($p{STRING});
+}
+
+$p{FORMAT} = $p{FORMAT} || $suffix || 'genbank';
 
 #The output path must exist, and we'll need it to end with a slash
-$p{OUTPUT} = $p{OUTPUT} || ".";
-$p{OUTPUT} .= "/" if (substr($p{OUTPUT}, -1, 1) !~ /[\/]/);
+$p{OUTPUT} = $p{OUTPUT} || q{.};
+$p{OUTPUT} = $GD->endslash($p{OUTPUT});
 die "\n GDERROR: $p{OUTPUT} does not exist.\n"
   if ($p{OUTPUT} && ! -e $p{OUTPUT});
 
@@ -69,11 +83,11 @@ my @fileswritten;
 my @seqstowrite;
 
 my %works = ();
-foreach my $org (split (",", $p{ORGS}))
+foreach my $org (split (q{,}, $p{ORGS}))
 {
   $works{$org} = {on => $org, path => undef};
 }
-foreach my $file ( split ( ",", $p{FILES} ) )
+foreach my $file ( split ( q{,}, $p{FILES} ) )
 {
   $works{$file} = {on => basename($file), path => $file};
 }
@@ -97,11 +111,11 @@ while ( my $obj = $iterator->next_seq() )
       );
       if ($p{SPLIT})
       {
-        my $outputfilename = $newobj->id . $GDS . "." . $p{FORMAT};
-        $GD->export_seqs(-filename =>$outputfilename,
-                         -sequences => [$newobj],
-                         -format => $p{FORMAT});
-        push @fileswritten, $outputfilename;
+        push @fileswritten, $GD->export_seqs(
+          -filepath  => $p{OUTPUT} . $newobj->id . $GDS,
+          -sequences => [$newobj],
+          -format    => $p{FORMAT},
+        );
       }
       else
       {
@@ -110,22 +124,30 @@ while ( my $obj = $iterator->next_seq() )
     }
   }
 }
-if (scalar @seqstowrite)
+if ($p{STRING})
 {
-  my $outputfilename = $filename . $GDS . "." . $p{FORMAT};
-  $GD->export_seqs(
-    -filename  => $outputfilename,
-    -sequences => \@seqstowrite,
-    -path      => $p{OUTPUT},
-    -format    => $p{FORMAT}
-  );
-  push @fileswritten, $outputfilename;
+  if (scalar @seqstowrite)
+  {
+    print $seqstowrite[0]->seq, "\n";
+  }
+  else
+  {
+    print "0\n";
+  }
 }
+elsif ($p{INPUT})
+{
+  push @fileswritten, $GD->export_seqs(
+    -filepath  => $p{OUTPUT} . $filename . $GDS,
+    -sequences => \@seqstowrite,
+    -format    => $p{FORMAT},
+  );
 
-print "\n";
-print "Wrote " . $p{OUTPUT} . "$_\n" foreach @fileswritten;
-print "\n";
-print $GD->attitude() . " brought to you by $GDV\n\n";
+  print "\n";
+  print "Wrote $_\n" foreach @fileswritten;
+  print "\n";
+  print $GD->attitude() . " brought to you by $GDV\n\n";
+}
 
 exit;
 
@@ -137,7 +159,7 @@ __END__
 
 =head1 VERSION
 
-  Version 5.53
+  Version 5.54
 
 =head1 DESCRIPTION
 
@@ -174,19 +196,21 @@ __END__
 
   -r OR -org must be provided. If both are given the table will be treated as
       another organism, named after the table's filename.
-      
+
   Generate high and most different sequences given the yeast rscu table
     ./GD_Juggle_Codons.pl -i sequences.FASTA -org yeast\
                                                  -a most_different_sequence,high
-    
+
   Use my rscu table to generate balanced sequences
     ./GD_Juggle_Codons.pl -i seqs.FASTA -r /my/dir/myrscu.rscu -a balanced
 
+  Use my rscu table to pipeline balanced sequences
+    ./GD_Juggle_Codons.pl -st ATCGATCCC -r /my/dir/myrscu.rscu -a balanced
+
 =head1 ARGUMENTS
 
 Required arguments:
 
-  -i,   --input : a file containing nucleotide sequences.
   -org, --organism : an organism whose RSCU table can be found in the config
       directory, or several separated by commas
     AND/OR
@@ -196,14 +220,17 @@ Optional arguments:
 
   -a,   --algorithm : which algorithms to use (see above), comma separated
           defaults to balanced
+  -i,   --input : a file containing nucleotide sequences
+  -st.  --string : a string containing DNA only - the program will return a
+          DNA only string. this is intended for pipelining.
   -out, --output : path to an output directory
   -f,   --format : default genbank
-  -s,   --split : output all sequences as separate files
+  -sp,  --split : output all sequences as separate files
   -h,   --help : Display this message
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014, GeneDesign developers
+Copyright (c) 2015, GeneDesign developers
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification,
