@@ -8,7 +8,7 @@ use Pod::Usage;
 use strict;
 use warnings;
 
-my $VERSION = '5.53';
+my $VERSION = '5.54';
 my $GDV = "GD_Reverse_Translate_$VERSION";
 my $GDS = "_RT";
 
@@ -33,7 +33,7 @@ pod2usage(-verbose=>99, -sections=>"NAME|VERSION|DESCRIPTION|ARGUMENTS|USAGE")
   if ($p{HELP});
 
 my $GD = Bio::GeneDesign->new();
-  
+
 #The input file must exist and be a format we care to read.
 die "\n GDERROR: You must supply an input file.\n"
   if (! $p{INPUT});
@@ -42,18 +42,18 @@ my ($iterator, $filename, $suffix) = $GD->import_seqs($p{INPUT});
 $p{FORMAT} = $p{FORMAT} || $suffix || "genbank";
 
 #The output path must exist, and we'll need it to end with a slash
-$p{OUTPUT} = $p{OUTPUT} || ".";
-$p{OUTPUT} .= "/" if (substr($p{OUTPUT}, -1, 1) !~ /[\/]/);
+$p{OUTPUT} = $p{OUTPUT} || q{.};
+$p{OUTPUT} = $GD->endslash($p{OUTPUT});
 die "\n GDERROR: $p{OUTPUT} does not exist.\n"
   if ($p{OUTPUT} && ! -e $p{OUTPUT});
-  
+
 #We must get a list of organisms or a set of rscu files
 die "\n GDERROR: Neither an organism nor an RSCU table were supplied.\n"
   if (! $p{ORGS} && ! $p{FILES});
 
 $p{ORGS}       = $p{ORGS}       ? $p{ORGS}       : q{};
 $p{FILES}      = $p{FILES}      ? $p{FILES}      : q{};
-$p{ALGORITHM}  = $p{ALGORITHM}  ? $p{ALGORITHM}  : "high";
+$p{ALGORITHM}  = $p{ALGORITHM}  ? $p{ALGORITHM}  : "balanced";
 
 ################################################################################
 ################################# CONFIGURING ##################################
@@ -79,24 +79,23 @@ while ( my $obj = $iterator->next_seq() )
   foreach my $work (keys %works)
   {
     $GD->set_organism(
-        -organism_name => $works{$work}->{on},
-        -rscu_path     => $works{$work}->{path});
-    
+      -organism_name => $works{$work}->{on},
+      -rscu_path     => $works{$work}->{path}
+    );
+
     my $newobj = $GD->reverse_translate(
-        -peptide => $obj,
-        -algorithm => $p{ALGORITHM});
-        
+      -peptide => $obj,
+      -algorithm => $p{ALGORITHM}
+    );
+
     if ($p{SPLIT})
     {
-      my $outputfilename = $obj->id . $GDS . "." . $p{FORMAT};
-      $GD->export_seqs(
-          -filename   => $outputfilename,
-          -path       => $p{OUTPUT},
-          -format     => $p{FORMAT},
-          -sequences  => [$obj]);
-      push @fileswritten, $outputfilename;
+      push @fileswritten, $GD->export_seqs(
+        -filepath   => $p{OUTPUT} . $obj->id . $GDS,
+        -format     => $p{FORMAT},
+        -sequences  => [$obj],
+      );
     }
-
     else
     {
       push @seqstowrite, $newobj;
@@ -105,17 +104,15 @@ while ( my $obj = $iterator->next_seq() )
 }
 if (scalar @seqstowrite)
 {
-  my $outputfilename = $filename . $GDS . "." . $p{FORMAT};
-  $GD->export_seqs(
-          -filename   => $outputfilename,
-          -path       => $p{OUTPUT},
-          -format     => $p{FORMAT},
-          -sequences  => \@seqstowrite);
-  push @fileswritten, $outputfilename;
+  push @fileswritten, $GD->export_seqs(
+    -filepath   => $p{OUTPUT} . $filename . $GDS,
+    -format     => $p{FORMAT},
+    -sequences  => \@seqstowrite,
+  );
 }
 
 print "\n";
-print "Wrote " . $p{OUTPUT} . "$_\n" foreach @fileswritten;
+print "Wrote $_\n" foreach @fileswritten;
 print "\n";
 print $GD->attitude() . " brought to you by $GDV\n\n";
 
@@ -129,21 +126,21 @@ __END__
 
 =head1 VERSION
 
-  Version 5.53
+  Version 5.54
 
 =head1 DESCRIPTION
 
   Given at least one protein sequence as input, the Reverse_Translate script
   generates synonymous nucleotide sequences using either a user-defined RSCU
   table or an RSCU table provided by GeneDesign
-  
+
   If no algorithm is specified, the balanced algorithm will be used. These are
   the algorithms provided by default with GeneDesign; you can make your own; see
   developer docs.
 
   Output will be named according to the name of the input file, and will be
   tagged with the suffix _RT.
-  
+
   Algorithms:
     high: The high algorithm replaces every codon in the input sequence with
         the most translationally optimal codon as specified by the input RSCU
@@ -151,12 +148,12 @@ __END__
         already the ideal codon it is left alone.
     balanced: The balanced algorithm uses the rscu data to determine a
          likelihood of codon replacement.
-         
+
 =head1 USAGE
 
   -r OR -o must be provided. If both are given the table will be treated as
       another organism, named after the table's filename.
-      
+
 =head1 ARGUMENTS
 
 Required arguments:
@@ -180,7 +177,7 @@ Optional arguments:
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014, GeneDesign developers
+Copyright (c) 2015, GeneDesign developers
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification,
