@@ -8,7 +8,7 @@ use File::Basename;
 use strict;
 use warnings;
 
-my $VERSION = '5.53';
+my $VERSION = '5.54';
 my $GDV = "GD_Sequence_Subtraction_$VERSION";
 my $GDS = "_SS";
 
@@ -36,7 +36,7 @@ pod2usage(-verbose=>99, -sections=>"NAME|VERSION|DESCRIPTION|ARGUMENTS|USAGE")
   if ($p{HELP});
 
 my $GD = Bio::GeneDesign->new();
-  
+
 #The input file must exist and be a format we care to read.
 die "\n GDERROR: You must supply an input file.\n"
   if (! $p{INPUT});
@@ -131,11 +131,14 @@ while ( my $obj = $iterator->next_seq() )
   foreach my $work (keys %works)
   {
     print "Performing changes for organism " . $works{$work}->{on} . "...\n";
+    my $olddesc = $obj->desc();
     $GD->set_organism(
         -organism_name => $works{$work}->{on},
         -rscu_path     => $works{$work}->{path});
 
     my $oldpep = $GD->translate(-sequence => $clone);
+    my @minuslist = ();
+    my @misslist = ();
     foreach my $tar (@TAROBJS)
     {
       my $id = $tar->id;
@@ -146,7 +149,7 @@ while ( my $obj = $iterator->next_seq() )
       my $precount = scalar(keys %$prepcount);
       unless ($precount)
       {
-        print "\t" . $obj->id . " has no occurences of $id\n";
+        #print "\t" . $obj->id . " has no occurences of $id\n";
         next;
       }
       $obj = $GD->subtract_sequence(
@@ -162,12 +165,12 @@ while ( my $obj = $iterator->next_seq() )
       {
         warn "\tGDWARNING: Failed to remove $oops of $precount instances of $id"
             . " from " . $obj->id . "\n";
-        $obj->desc($obj->desc . "[~$id]");
+        push @misslist, $id;
       }
       else
       {
         print  "\t$precount instance$s of $id removed from " . $obj->id . "\n";
-        $obj->desc($obj->desc . "[-$id]");
+        push @minuslist, $id;
       }
       my $newpep = $GD->translate(-sequence => $obj);
       if ( $newpep->seq ne $oldpep->seq)
@@ -177,15 +180,28 @@ while ( my $obj = $iterator->next_seq() )
       }
     }
     
+    if (scalar @minuslist || scalar @misslist)
+    {
+      $obj->desc($olddesc . " subtracted with $works{$work}->{on} RSCU values");
+    }
+    if (scalar @minuslist)
+    {
+      my $minusstring = join ',', @minuslist; 
+      $obj->desc($obj->desc . " [-$minusstring]");
+    }
+    if (scalar @misslist)
+    {
+      my $missstring = join ',', @misslist; 
+      $obj->desc($obj->desc . " [~$missstring]");
+    }
+
     if ($p{SPLIT})
     {
-      my $outputfilename = $obj->id . $GDS . "." . $p{FORMAT};
-      $GD->export_seqs(
-          -filename   => $outputfilename,
-          -path       => $p{OUTPUT},
-          -format     => $p{FORMAT},
-          -sequences  => [$obj]);
-      push @fileswritten, $outputfilename;
+      push @fileswritten, $GD->export_seqs(
+        -filepath   => $p{OUTPUT} . $obj->id . $GDS,
+        -format     => $p{FORMAT},
+        -sequences  => [$obj],
+      );
     }
     else
     {
@@ -195,17 +211,15 @@ while ( my $obj = $iterator->next_seq() )
 }
 if (scalar @seqstowrite)
 {
-  my $outputfilename = $filename . $GDS . "." . $p{FORMAT};
-  $GD->export_seqs(
-          -filename   => $outputfilename,
-          -path       => $p{OUTPUT},
-          -format     => $p{FORMAT},
-          -sequences  => \@seqstowrite);
-  push @fileswritten, $outputfilename;
+  push @fileswritten, $GD->export_seqs(
+    -filepath   => $p{OUTPUT} . $filename . $GDS,
+    -format     => $p{FORMAT},
+    -sequences  => \@seqstowrite,
+  );
 }
 
 print "\n";
-print "Wrote " . $p{OUTPUT} . "$_\n" foreach @fileswritten;
+print "Wrote $_\n" foreach @fileswritten;
 print "\n";
 print $GD->attitude() . " brought to you by $GDV\n\n";
 
@@ -219,7 +233,7 @@ __END__
 
 =head1 VERSION
 
-  Version 5.53
+  Version 5.54
 
 =head1 DESCRIPTION
 
@@ -238,7 +252,7 @@ __END__
 =head1 USAGE
 
   -e OR -s must be provided. If both are given both will be processed.
-      
+
 =head1 ARGUMENTS
 
 Required arguments:
@@ -268,7 +282,7 @@ Optional arguments:
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014, GeneDesign developers
+Copyright (c) 2015, GeneDesign developers
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification,
