@@ -8,7 +8,7 @@ Bio::GeneDesign::Basic
 
 =head1 VERSION
 
-Version 5.53
+Version 5.54
 
 =head1 DESCRIPTION
 
@@ -29,18 +29,22 @@ use Carp;
 use strict;
 use warnings;
 
-our $VERSION = 5.53;
+our $VERSION = 5.54;
 
 use base qw(Exporter);
 our @EXPORT_OK = qw(
+  _generate_dimers
   _sanitize
   _count
+  _gcwindows
   _ntherm
   _complement
+  _toRNA
   _melt
   _regres
   _regarr
   _positions
+  _find_runs
   _is_ambiguous
   _compare_sequences
   _amb_transcription
@@ -61,21 +65,25 @@ our %EXPORT_TAGS =  (GD=> \@EXPORT_OK);
 our @BASES = qw(A T C G);
 
 our %NTIDES = (
-  A => [qw(A)],     T => [qw(T)],     C => [qw(C)],     G => [qw(G)],
-  R => [qw(A G)],   Y => [qw(C T)],   W => [qw(A T)],   S => [qw(C G)],
-  K => [qw(G T)],   M => [qw(A C)],   B => [qw(C G T)], D => [qw(A G T)],
-  H => [qw(A C T)], V => [qw(A C G)], N => [qw(A C G T)]
+  A => [qw(A)],     T => [qw(T)],
+  C => [qw(C)],     G => [qw(G)],
+  R => [qw(A G)],   Y => [qw(C T)],
+  W => [qw(A T)],   S => [qw(C G)],
+  K => [qw(G T)],   M => [qw(A C)],
+  B => [qw(C G T)], D => [qw(A G T)],
+  H => [qw(A C T)], V => [qw(A C G)],
+  N => [qw(A C G T)],
 );
 
 my %REGHSH = (
-  A => "A",         T => "T",
-  C => "C",         G => "G",
-  R => "[AGR]",     Y => "[CTY]",
-  W => "[ATW]",     S => "[CGS]",
-  K => "[GKT]",     M => "[ACM]",
-  B => "[BCGKSTY]", D => "[ADGKRTW]",
-  H => "[ACHMTWY]", V => "[ACGMRSV]",
-  N => "[ABCDGHKMNRSTVWY]"
+  A => 'A',         T => 'T',
+  C => 'C',         G => 'G',
+  R => '[AGR]',     Y => '[CTY]',
+  W => '[ATW]',     S => '[CGS]',
+  K => '[GKT]',     M => '[ACM]',
+  B => '[BCGKSTY]', D => '[ADGKRTW]',
+  H => '[ACHMTWY]', V => '[ACGMRSV]',
+  N => '[ABCDGHKMNRSTVWY]',
 );
 
 our $ambnt    = qr/[R Y W S K M B D H V N]+/x;
@@ -84,11 +92,11 @@ our %AACIDS = map { $_ => $_ } qw(A C D E F G H I K L M N P Q R S T V W Y);
 $AACIDS{"*"} = "[\*]";
 
 our %AA_NAMES = (
-  A => "Ala", B => "Unk", C => "Cys", D => "Asp", E => "Glu", F => "Phe",
-  G => "Gly", H => "His", I => "Ile", J => "Unk", K => "Lys", L => "Leu",
-  M => "Met", N => "Asn", O => "Unk", P => "Pro", Q => "Gln", R => "Arg",
-  S => "Ser", T => "Thr", U => "Unk", V => "Val", W => "Trp", X => "Unk",
-  Y => "Tyr", Z => "Unk","*" => "Stp");
+  A => 'Ala', B => 'Unk', C => 'Cys', D => 'Asp', E => 'Glu', F => 'Phe',
+  G => 'Gly', H => 'His', I => 'Ile', J => 'Unk', K => 'Lys', L => 'Leu',
+  M => 'Met', N => 'Asn', O => 'Unk', P => 'Pro', Q => 'Gln', R => 'Arg',
+  S => 'Ser', T => 'Thr', U => 'Unk', V => 'Val', W => 'Trp', X => 'Unk',
+  Y => 'Tyr', Z => 'Unk', '*' => 'Stp');
 
 # entropy, enthalpy, and free energy of paired bases
 my %EEG = (
@@ -104,6 +112,23 @@ my %EEG = (
 
 =head1 Functions
 
+=head2 _generate_dimers
+
+=cut
+
+sub _generate_dimers
+{
+  my @dimers;
+  foreach my $a (@BASES)
+  {
+    foreach my $b (@BASES)
+    {
+      push @dimers, $a . $b;
+    }
+  }
+  return @dimers;
+}
+
 =head2 _sanitize()
 
 remove non nucleotide characters from nucleotide sequences. remove non amino
@@ -155,28 +180,80 @@ sub _count
   my $len = length $strand;
   my @arr = split q{}, uc $strand;
   my %C = map {$_ => 0} keys %NTIDES;
-  
+
   #Count bases
   $C{$_}++ foreach @arr;
-  
+
   $C{d} += $C{$_} foreach (qw(A T C G));
   $C{n} += $C{$_} foreach (qw(B D H K M N R S V W Y));
   $C{'?'} = ($C{d} + $C{n}) - $len;
-  
+
   #Estimate how many of each degenerate base would be a G or C
   my $split = .5*$C{R}  + .5*$C{Y}  + .5*$C{K}  + .5*$C{M}  + .5*$C{N};
   my $trip  = (2*$C{B} / 3) + (2*$C{V} / 3) + ($C{D} / 3) + ($C{H} / 3);
-  
+
   #Calculate GC/AT percentage
   my $gcc = $C{S} + $C{G} + $C{C} + $split + $trip;
   my $gcp = sprintf "%.1f", ($gcc / $len) * 100;
   $C{GCp} = $gcp;
   $C{ATp} = 100 - $gcp;
   $C{len} = $len;
-  
+
   return \%C;
 }
 
+=head2 _gcwindows()
+
+takes a nucleotide sequence, a window size, and minimum and maximum values.
+returns lists of real coordinates of subsequences that violate mimimum or
+maximum GC percentages.
+
+Values are returned inside an array reference such that the first value is an
+array ref of minimum violators (as array refs of left/right coordinates), and
+the second value is an array ref of maximum violators.
+
+$return_value = [
+  [[left, right], [left, right]], #minimum violators
+  [[left, right], [left, right]]  #maximum violators
+];
+
+=cut
+
+sub _gcwindows
+{
+  my ($seq, $winsize, $min, $max) = @_;
+  my @minflags = ();
+  my @maxflags = ();
+  my $seqlen = length $seq;
+  my $lefpos = 0;
+  my $rigpos = $winsize - 1;
+  my $win = substr $seq, $lefpos, $winsize;
+  my %hsh = (G => 0, C => 0, A => 0, T => 0);
+  $hsh{$_}++ foreach (split q{}, $win);
+  my $initbase = substr $seq, $lefpos, 1;
+  my $lastbase = substr $seq, $rigpos, 1;
+  while ($rigpos < $seqlen)
+  {
+    my $GCperc = 100 * (($hsh{G} + $hsh{C}) / $winsize);
+    $lefpos++;
+    $rigpos++;
+    if ($GCperc < $min)
+    {
+      push @minflags, [$lefpos, $rigpos];
+    }
+    if ($GCperc > $max)
+    {
+      push @maxflags, [$lefpos, $rigpos];
+    }
+    $hsh{$initbase}--;
+    $initbase = substr $seq, $lefpos, 1;
+    $lastbase = substr $seq, $rigpos, 1;
+    $hsh{$lastbase}++;
+  }
+  
+  return [\@minflags, \@maxflags];
+}
+
 =head2 _melt()
 
 takes a nucleotide sequence and returns a melting temperature
@@ -220,7 +297,7 @@ takes a nucleotide sequence and returns a nearest neighbor melting temp.
 
   in: nucleotide sequence (string)
   out: temperature (float)
-  
+
 =cut
 
 sub _ntherm
@@ -262,11 +339,22 @@ sub _complement
   return $strand;
 }
 
+=head2 _toRNA()
+
+=cut
+
+sub _toRNA
+{
+  my ($strand) = @_;
+  $strand =~ tr/Tt/Uu/;
+  return $strand;
+}
+
 =head2 _regres()
 
 takes a  sequence that may be degenerate and returns a string that is prepped
 for use in a regular expression.
-  
+
   in: sequence (string),
       switch for aa or nt sequence (1 or null)
   out: regexp string (string)
@@ -294,7 +382,7 @@ sub _regres
       $comp .= $aa;
     }
   }
-  return qr/$comp/x;
+  return qr/$comp/ix;
 }
 
 =head2 regarr()
@@ -331,6 +419,30 @@ sub _positions
   return $temphash;
 }
 
+=head2 _find_runs
+
+=cut
+
+sub _find_runs
+{
+  my ($seq, $pattern, $min) = @_;
+  my @arr = ();
+  $min = $min || 5;
+  if (_is_ambiguous($pattern))
+  {
+    die "Ambiguous pattern passed to _find_runs";
+  }
+  my $reg = '[' . $pattern . ']';
+  while ($seq =~ m{(($pattern) {$min,})}msixg)
+  {
+    my $len = length $1;
+    my $rig = pos $seq;
+    my $lef = $rig - $len + 1;
+    push @arr, [$lef, $rig];
+  }
+  return \@arr;
+}
+
 =head2 _is_ambiguous
 
 =cut
@@ -346,7 +458,7 @@ sub _is_ambiguous
 
 takes two nucleotide sequences that are assumed to be perfectly aligned and
 roughly equivalent and returns similarity metrics. should be twweeaakkeedd
-  
+
   in: 2x nucleotide sequence (string)
   out: similarity metrics (hash)
 
@@ -387,12 +499,12 @@ sub _amb_transcription
   my $prseq = uc $ntseq;
   my (@SEED, @NEW) = ((), ());
   my $offset = 0;
-  my $ntlen = length($prseq);
+  my $ntlen = length $prseq;
   while ($offset < $ntlen)
   {
-    my $template = substr($prseq, $offset, 1);
+    my $template = substr $prseq, $offset, 1;
     my $ntides = $NTIDES{$template};
-    my $possibilities = scalar(@$ntides);
+    my $possibilities = scalar @$ntides;
     if ($possibilities == 1)
     {
       @SEED = ( $template ) if ($offset == 0);
@@ -419,7 +531,7 @@ sub _amb_transcription
 
 Basically builds a list of tree nodes for the amb_trans* functions.
 in: 2 x peptide lists (array reference) out: combined list of peptides
-  
+
 =cut
 
 sub _add_arr
@@ -444,7 +556,7 @@ __END__
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014, GeneDesign developers
+Copyright (c) 2015, GeneDesign developers
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification,
