@@ -8,7 +8,7 @@ GeneDesign::Codons
 
 =head1 VERSION
 
-Version 5.53
+Version 5.54
 
 =head1 DESCRIPTION
 
@@ -27,12 +27,13 @@ use Bio::GeneDesign::Basic qw(:GD);
 use Math::Combinatorics qw(combine);
 use List::Util qw(max first);
 use File::Basename;
+use autodie qw(open close);
 use Carp;
 
 use strict;
 use warnings;
 
-our $VERSION = 5.53;
+our $VERSION = 5.54;
 
 use base qw(Exporter);
 our @EXPORT_OK = qw(
@@ -73,7 +74,7 @@ sub _parse_organisms
   {
     my $name = basename($table);
     $name =~ s{\.[^.]+$}{}x;
-    if ($table =~ /\.rscu\Z/x)
+    if ($table =~ m{\.rscu\Z}x)
     {
       $orgs->{$name} = $path . $table;
     }
@@ -93,7 +94,7 @@ sub _parse_organisms
 sub _parse_codon_file
 {
   my ($path) = @_;
-  open (my $CFILE, "<", $path) || croak "Can't open $path : $!";
+  open (my $CFILE, '<', $path);
   my $ref = do { local $/ = <$CFILE> };
   close $CFILE;
   my @lines = split(/\n/x, $ref);
@@ -123,14 +124,14 @@ sub _parse_codon_file
 Takes a codon table hashref and reverses it such that each key is a one letter
 amino acid residue and each value is an array reference containing all of the
 codons that can code for that residue.
-  
+
 =cut
 
 sub _reverse_codon_table
 {
   my ($codontable) = @_;
   my $revcodon_t = {};
-  foreach my $codon (keys %$codontable)
+  foreach my $codon (sort {$a cmp $b} keys %$codontable)
   {
     my $aa = $codontable->{$codon};
     $revcodon_t->{$aa} = [] if ( ! exists $revcodon_t->{$aa} );
@@ -143,20 +144,29 @@ sub _reverse_codon_table
 
 takes a nucleotide sequence, a frame, and a codon table and returns that frame
 translated into amino acids.
-  
+
 =cut
 
 sub _translate
 {
   my ($nucseq, $frame, $codon_t) = @_;
-  croak ("translate requires an unambiguous nucleotide sequence\n")
-    if ($nucseq =~ $ambnt);
   $nucseq = _complement($nucseq, 1) if ($frame < 0);
   my $peptide = q{};
-  for (my $offset = abs($frame)-1; $offset < length($nucseq); $offset += 3)
+  my $limit = length $nucseq;
+  my $offset = abs($frame) - 1;
+  $limit-- while (($limit - $offset) % 3 != 0);
+  while ($offset < $limit)
   {
-    my $codon = substr($nucseq, $offset, 3);
-    $peptide .= $codon_t->{$codon} if (exists $codon_t->{$codon});
+    my $codon = substr $nucseq, $offset, 3;
+    if (exists $codon_t->{$codon})
+    {
+      $peptide .= $codon_t->{$codon};
+    }
+    else
+    {
+      carp("GDWarning: $codon is untranslatable\n");
+    }
+    $offset += 3;
   }
   return $peptide;
 }
@@ -170,20 +180,20 @@ sub _subtract
   my ($oldseq, $pattern, $regarr, $codon_t, $rscu_t, $revcodon_t) = @_;
   my $seq = $oldseq;
   my $temphash = _positions($seq, $regarr);
-  foreach my $gpos (keys %$temphash)
+  foreach my $gpos (sort keys %{$temphash})
   {
-    my $framestart = ($gpos) % 3;
-    my $startpos = int( length($temphash->{$gpos}) / 3 + 2 ) * 3;
-    my $string = substr($seq, $gpos - $framestart, $startpos);
+    my $framestart = $gpos % 3;
+    my $startpos = int ( (length $temphash->{$gpos}) / 3 + 2 ) * 3;
+    my $string = substr $seq, $gpos - $framestart, $startpos;
     my $newrepseg = $string;
-    
+
     my %newseqs;
-    my $len = length($string)/3;
+    my $len = (length $string) / 3;
     my $curval = _rscu_sum($rscu_t, $string);
     #compute the changes possible
     for my $it (1..$len)
     {
-      my @map = map { join q{}, sort @$_ } combine($it,(1..$len));
+      my @map = map { join q{}, sort @{$_} } combine($it, (1..$len));
       foreach my $guide (@map)
       {
         my $rscuers = {};
@@ -193,15 +203,14 @@ sub _subtract
         foreach my $coord (@coords)
         {
           my $srcarr = $rscuers->{$passthrough};
-          foreach my $str (@$srcarr)
+          foreach my $str (@{$srcarr})
           {
-            my $coda = substr($str, $coord*3-3, 3);
+            my $coda = substr $str, ($coord * 3) - 3, 3;
             foreach my $codb (grep {$coda ne $_}
                               @{$revcodon_t->{$codon_t->{$coda}}})
             {
               my $newstr = $str;
-              #substr($newstr, $coord*3-3, 3) = $codb;
-              substr($newstr, $coord*3-3, 3, $codb);
+              substr $newstr, ($coord * 3) - 3, 3, $codb;
               push @{$rscuers->{$passthrough+1}}, $newstr;
             }
           }
@@ -220,21 +229,26 @@ sub _subtract
                            || $newseqs{$a}->[1] <=> $newseqs{$b}->[1]}
                         keys %newseqs)
     {
-      if ($newseq !~ $pattern && _complement($newseq, 1) !~ $pattern)
+      my $qeswen = _complement($newseq, 1);
+      my $matchflag = 0;
+      foreach my $regex (@{$regarr})
+      {
+        $matchflag++ if ($newseq =~ $regex);
+        $matchflag++ if ($qeswen =~ $regex);
+      }
+      if ($matchflag == 0)
       {
         $newrepseg = $newseq;
         last;
       }
     }
-                                    
-    #substr($seq, $gpos - $framestart, length($newrepseg)) = $newrepseg;
-    substr($seq, $gpos - $framestart, length($newrepseg), $newrepseg);
+    substr $seq, $gpos - $framestart, (length $newrepseg), $newrepseg;
   }
   return $seq;
 }
 
 =head2 _rscu_sum()
-  
+
 =cut
 
 sub _rscu_sum
@@ -242,10 +256,11 @@ sub _rscu_sum
   my ($rscu_t, $ntseq) = @_;
   my $offset = 0;
   my $rscusum = 0;
-  my $length = length($ntseq);
-  while ($offset < $length)
+  my $length = length $ntseq;
+  my $rem = $length % 3;
+  while ($offset < ($length - $rem))
   {
-    my $cod = substr($ntseq, $offset, 3);
+    my $cod = substr $ntseq, $offset, 3;
     $rscusum += $rscu_t->{$cod};
     $offset += 3;
   }
@@ -256,13 +271,13 @@ sub _rscu_sum
 
 takes a reference to an array of sequences and returns a hash with codons as
 keys and the number of times the codon occurs as a value.
-  
+
 =cut
 
 sub _codon_count
 {
   my ($seqs, $codon_t, $hashref) = @_;
-  my %blank = map {$_ => 0} keys %$codon_t;
+  my %blank = map {$_ => 0} sort keys %$codon_t;
   my $codoncount = $hashref || \%blank;
   foreach my $seq (@$seqs)
   {
@@ -280,7 +295,7 @@ sub _codon_count
 takes a hash reference with keys as codons and values as number of times
 those codons occur (it helps to use codon_count) and returns a hash with each
 codon and its RSCU value
-  
+
 =cut
 
 sub _generate_RSCU_table
@@ -387,7 +402,7 @@ of all amino acid sequences that nucleotide sequence could be translated into.
       optional switch to force only a single frame of translation
       optional hashref of previous answers to speed processing
   out: amino acid sequence list (vector)
-  
+
 =cut
 
 sub _amb_translation
@@ -446,7 +461,7 @@ previous answers, it will run MUCH faster (memoization).
   in: codon (string),
       codon table (hash reference)
   out: amino acid list (vector)
-  
+
 =cut
 
 sub _degcodon_to_aas
@@ -503,7 +518,7 @@ scores.
       RSCU table (hashref)
   out: new gene sequence (string)
   #NO UNIT TEST
-  
+
 =cut
 
 sub _minimize_local_alignment_dp
@@ -602,7 +617,7 @@ pattern can be inserted out of frame.
       amino acid sequence (string),
       codon table (hash reference)
   out: nucleotide pattern (string)
-  
+
 =cut
 
 sub _pattern_aligner
@@ -649,7 +664,7 @@ pattern (if possible).
       nucleotide pattern (string),
       codon table (hash reference)
   out: nucleotide sequence (string) OR null
-  
+
 =cut
 
 sub _pattern_adder
@@ -717,7 +732,7 @@ __END__
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014, GeneDesign developers
+Copyright (c) 2015, GeneDesign developers
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification,
