@@ -8,12 +8,12 @@ Bio::GeneDesign::Graph
 
 =head1 VERSION
 
-Version 5.53
+Version 5.54
 
 =head1 DESCRIPTION
 
 make graphs
-  
+
 =head1 AUTHOR
 
 Sarah Richardson <SMRichardson@lbl.gov>.
@@ -30,7 +30,7 @@ use GD::Image;
 use strict;
 use warnings;
 
-our $VERSION = 5.53;
+our $VERSION = 5.54;
 
 use base qw(Exporter);
 our @EXPORT_OK = qw(
@@ -50,10 +50,10 @@ our %EXPORT_TAGS =  (GD => \@EXPORT_OK);
 sub _make_graph
 {
   my ($arrref, $window, $orgname, $codon_t, $rscu_t, $revcodon_t) = @_;
-  
+
   my @sizes = sort {$b <=> $a} map {length($_->seq)} @$arrref;
   my $maxlen = $sizes[0];
-  
+
   my $graph = GD::Graph::lines->new(1024, 768);
   my @colors = reverse sorted_colour_list(29);
   $graph->set(
@@ -80,7 +80,7 @@ sub _make_graph
                keys %$codon_t;
   my %perc_t = map {$_ => $rscu_t->{$_} / $AAfams{$_}}
                keys %$codon_t;
-  
+
   foreach my $seqobj (@$arrref)
   {
     my ($x, $y)  = index_codon_percentages($seqobj->seq, $window, \%perc_t);
@@ -125,7 +125,7 @@ sub _dotplot
           $match++;
         }
       }
-      if ($match >= $stringency)
+      if (100 * ($match / $winsize) >= $stringency)
       {
         $BitMap->setPixel($i, $j, $black);
       }
@@ -148,7 +148,7 @@ Generates two arrays for x and y values of a graph of codon percentage values.
       window size (integer),
       codon percentage table (hash reference)
   out: x values (array reference), y values (array reference)
-  
+
 =cut
 
 sub index_codon_percentages
@@ -179,7 +179,7 @@ __END__
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014, GeneDesign developers
+Copyright (c) 2015, GeneDesign developers
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification,
