@@ -8,7 +8,7 @@ GeneDesign::PrefixTree - A suffix tree implementation for nucleotide searching
 
 =head1 VERSION
 
-Version 5.53
+Version 5.54
 
 =head1 DESCRIPTION
 
@@ -27,7 +27,7 @@ use 5.006;
 use strict;
 use warnings;
 
-my $VERSION = 5.53;
+my $VERSION = 5.54;
 
 =head1 Functions
 
@@ -51,7 +51,7 @@ sub new
 
 Add suffixes to the tree. You can add a sequence, an id (which can be an array
 reference of ids), and a scalar note.
-  
+
     $tree->add_prefix('GGATCC', 'BamHI', "i hope this didn't pop up");
     $tree->add_prefix('GGCCC', ['OhnoI', 'WoopsII'], "I hope these pop up");
 
@@ -92,7 +92,7 @@ subsequence, and the 3 index is whatever note is associated with the
 subsequence.
 
   my @hits = $tree->find_prefixes('AAAGGATCCATCGCATACGAGGCCCCACCG');
-  
+
   # @hits = (['BamHI', 4, 'GGATCC', 'i hope this didn't pop up'],
   #          ['OhnoI', 21, 'GGCCC', 'I hope these pop up'],
   #          ['WoopsII', 21, 'GGCCC', 'I hope these pop up']
@@ -115,7 +115,7 @@ sub find_prefixes
     {
       if ($ref->{ids})
       {
-        foreach my $id (keys %{$ref->{ids}})
+        foreach my $id (sort {$a cmp $b} keys %{$ref->{ids}})
         {
           my $notes = $ref->{ids}->{$id};
           push @locations, [$id, $seq_idx + 1, $ref->{sequence}, $notes];
@@ -137,7 +137,7 @@ sequences and the values are hash references containing the ids and notes
 associated with each sequence in the tree.
 
   my %twos = $tree->find_ntons(2);
-  
+
   # %twos = ('GGGCC' => {'OhnoI' => ['I hope these pop up'],
   #                    'WoopsII' => ['I hope these pop up']}
   # );
@@ -151,7 +151,7 @@ sub find_ntons
   $n = $n || 1;
   my %ntons;
   my $root = $self->{ root };
-  my @nodes = map { $root->{$_} }keys %{$root};
+  my @nodes = map { $root->{$_} } sort {$a cmp $b} keys %{$root};
   foreach my $node (@nodes)
   {
     if (exists $node->{sequence} && $node->{count} == $n)
@@ -160,7 +160,7 @@ sub find_ntons
     }
     push @nodes, map { $node->{$_} }
                  grep {$_ ne 'sequence' && $_ ne 'ids' && $_ ne 'count'}
-                 keys %{$node};
+                 sort {$a cmp $b} keys %{$node};
   }
   return %ntons;
 }
@@ -170,7 +170,7 @@ __END__
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014, GeneDesign developers
+Copyright (c) 2015, GeneDesign developers
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification,
