@@ -8,12 +8,12 @@ GeneDesign::Random
 
 =head1 VERSION
 
-Version 5.53
+Version 5.54
 
 =head1 DESCRIPTION
 
 Random DNA Generators
-  
+
 =head1 AUTHOR
 
 Sarah Richardson <SMRichardson@lbl.gov>
@@ -30,7 +30,7 @@ use List::Util qw(shuffle);
 use strict;
 use warnings;
 
-our $VERSION = 5.53;
+our $VERSION = 5.54;
 
 use base qw(Exporter);
 our @EXPORT_OK = qw(
@@ -54,7 +54,7 @@ our %EXPORT_TAGS =  (GD => \@EXPORT_OK);
       stop codon prevention(0 stops allowed, else no stops),
       codon table (hash reference)
   out: nucleotide sequence (string)
-  
+
 =cut
 
 sub _randomDNA
@@ -70,31 +70,33 @@ sub _randomDNA
   my $Gstr = 'G' x $Gcount;
   my $Ccount  = $GCtotal - $Gcount;
   my $Cstr = 'C' x $Ccount;
-  
+
   #AT
   my $ATtotal = $len - $GCtotal;
   my $Acount  = sprintf "%.0f", rand( $ATtotal );
   my $Astr = 'A' x $Acount;
   my $Tcount  = $ATtotal - $Acount;
   my $Tstr = 'T' x $Tcount;
-  
+
   my @randomarray = shuffle( split( '', $Gstr . $Cstr . $Astr . $Tstr) );
   my $DNA = join('', @randomarray);
-  
+
   if ($stopswit)
   {
-    my $stoplist = _find_in_frame($DNA, "*", $codon_t);
-    foreach my $pos (@$stoplist)
+    my $stophsh = _find_in_frame($DNA, "*", $codon_t);
+    while (scalar keys %{$stophsh})
     {
-      my $bit = substr($DNA, (($pos + 1) * 3) - 3, 3);
-      #substr($DNA, (($pos + 1) * 3) - 3, 3) = scalar reverse($bit);
-      substr($DNA, (($pos + 1) * 3) - 3, 3, scalar reverse($bit));
-      if (int(rand(1)+.5) == 1)
+      foreach my $pos (keys %{$stophsh})
       {
-        my $bat = substr($DNA, (($pos + 1) * 3) - 2, 2);
-        #substr($DNA, (($pos + 1) * 3) - 2, 2) = scalar reverse($bat);
-        substr($DNA, (($pos + 1) * 3) - 2, 2, scalar reverse($bat));
+        my $bit = substr $DNA, $pos, 3;
+        substr $DNA, $pos, 3, scalar reverse $bit;
+        if (int(rand(1)+.5) == 1)
+        {
+          my $bat = substr $DNA, $pos, 2;
+          substr $DNA, $pos, 2, scalar reverse$bat;
+        }
       }
+      $stophsh = _find_in_frame($DNA, "*", $codon_t);
     }
   }
   return $DNA;
@@ -103,7 +105,7 @@ sub _randomDNA
 =head2 _randombase()
 
   when you just want one random base
-  
+
 =cut
 
 sub _randombase
@@ -115,14 +117,14 @@ sub _randombase
 =head2 _random_weighted_base()
 
   when you just want one random but weighted base
-  
+
 =cut
 
 sub _randombase_weighted
 {
   my ($GCp) = @_;
   return _randombase() unless ($GCp);
-  
+
   my $GCcount = $GCp/200 ;
   my $ATcount = (100-$GCp)/200;
   my $weight = {G => $GCcount, C => $GCcount, T => $ATcount, A => $ATcount};
@@ -130,7 +132,7 @@ sub _randombase_weighted
 }
 
 =head2 _weighted_rand()
-  
+
 =cut
 
 sub _weighted_rand
@@ -183,7 +185,7 @@ __END__
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014, GeneDesign developers
+Copyright (c) 2015, GeneDesign developers
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification,
