@@ -8,7 +8,7 @@ Bio::GeneDesign::RestrictionEnzyme
 
 =head1 VERSION
 
-Version 5.53
+Version 5.54
 
 =head1 DESCRIPTION
 
@@ -30,7 +30,7 @@ use warnings;
 
 use base qw(Bio::Root::Root);
 
-our $VERSION = 5.53;
+our $VERSION = 5.54;
 
 my $IIPreg  = qr/   ([A-Z]*)   \^ ([A-Z]*)      /x;
 my $IIAreg  = qr/\A \w+ \(([\-]*\d+) \/ ([\-]*\d+)\)\Z  /x;
@@ -61,9 +61,9 @@ constructor will ignore every other argument except for -start.
 Required arguments:
 
     EITHER
-        
+
         -enzyme : a Bio::GeneDesign::RestrictionEnzyme object to clone
-    
+
     OR
         -id     : The name of the enzyme (i.e., BamHI)
         -cutseq : The string describing the enzyme's recognition and cleavage
@@ -107,7 +107,7 @@ sub new
 {
   my ($class, @args) = @_;
   my $self = $class->SUPER::new(@args);
-  
+
   my ($object, $id, $cutseq, $temp, $tempin, $score, $methdam, $methdcm,
       $methcpg, $vendors, $staract, $buffers, $start, $exclude, $aggress) =
      $self->_rearrange([qw(ENZYME ID CUTSEQ TEMP TEMPIN SCORE METHDAM METHDCM
@@ -122,23 +122,23 @@ sub new
   }
   else
   {
-    
+
     $self->throw("No enzyme id defined") unless ($id);
-    $self->{'id'} = $id;
+    $self->{id} = $id;
 
     $self->throw("No cut sequence defined") unless ($cutseq);
-    $self->{'cutseq'} = $cutseq;
+    $self->{cutseq} = $cutseq;
 
     my $recseq = $cutseq;
     $recseq =~ s/\W*\d*//xg;
-    $self->{'recseq'} = $recseq;
+    $self->{recseq} = $recseq;
 
     #Regular expression arrayref to use for enzyme searching
     #Should store as compiled regexes instead
-    $self->{'regex'} = _regarr($recseq);
+    $self->{regex} = _regarr($recseq);
 
     my $sitelen = length($recseq);
-    $self->{'length'} = $sitelen;
+    $self->{length} = $sitelen;
 
     #Enzyme Class and Palindromy
     my ($lef, $rig) = (q{}, q{});
@@ -146,12 +146,12 @@ sub new
     {
       $lef = length($1);
       $rig = length($2);
-      $self->{'class'} = "IIP";
-      $self->{'classex'} = $IIPreg;
-      
+      $self->{class} = "IIP";
+      $self->{classex} = $IIPreg;
+
       if ($lef == $rig)
       {
-        $self->{'palindromy'} = "unknown";
+        $self->{palindromy} = "unknown";
       }
       else
       {
@@ -160,15 +160,15 @@ sub new
         my $mattersbit = substr($recseq, $inlef, length($recseq) - (2 * $inlef));
         if ($mattersbit && $mattersbit =~ $ambnt && length($mattersbit) % 2 == 0)
         {
-          $self->{'palindromy'} = "pnon";
+          $self->{palindromy} = "pnon";
         }
         elsif ($mattersbit && $mattersbit eq _complement($mattersbit, 1))
         {
-          $self->{'palindromy'} = "pal";
+          $self->{palindromy} = "pal";
         }
         elsif ($mattersbit)
         {
-          $self->{'palindromy'} = "nonpal";
+          $self->{palindromy} = "nonpal";
         }
       }
     }
@@ -176,21 +176,21 @@ sub new
     {
       $lef = int($1);
       $rig = int($2);
-      $self->{'class'} = "IIB";
-      $self->{'classex'} = $IIBreg;
-      $self->{'palindromy'} = "pnon";
+      $self->{class} = "IIB";
+      $self->{classex} = $IIBreg;
+      $self->{palindromy} = "pnon";
     }
     elsif ($cutseq =~ $IIAreg)
     {
       $lef = int($1);
       $rig = int($2);
-      $self->{'class'} = "IIA";
-      $self->{'classex'} = $IIAreg;
-      $self->{'palindromy'} = "pnon";
+      $self->{class} = "IIA";
+      $self->{classex} = $IIAreg;
+      $self->{palindromy} = "pnon";
     }
     else
     {
-      $self->{'class'} = "unknown";
+      $self->{class} = "unknown";
     }
 
     #Enzyme type
@@ -198,60 +198,60 @@ sub new
     if ($lef < $rig)
     {
       $type .= "5'";
-      $self->{'inside_cut'} = $lef;
-      $self->{'outside_cut'} = $rig;
+      $self->{inside_cut} = $lef;
+      $self->{outside_cut} = $rig;
     }
     elsif ($lef > $rig)
     {
       $type .= "3'";
-      $self->{'inside_cut'} = $rig;
-      $self->{'outside_cut'} = $lef;
+      $self->{inside_cut} = $rig;
+      $self->{outside_cut} = $lef;
     }
     elsif ($lef == $rig)
     {
-      $type .= "b";
+      $type .= 'b';
     }
-    $self->{'onebpoverhang'} = 1 if (abs($lef - $rig) == 1);
-    $self->{'type'} = $type;
+    $self->{onebpoverhang} = 1 if (abs($lef - $rig) == 1);
+    $self->{type} = $type;
 
-    $self->{'temp'} = $temp if ($temp);
+    $self->{temp} = $temp if ($temp);
     if ($tempin)
     {
       my ($intime, $intemp) = split q{@}, $tempin;
-      $self->{'tempin'} = $intemp;
-      $self->{'timein'} = $intime;
+      $self->{tempin} = $intemp;
+      $self->{timein} = $intime;
     }
 
-    $self->{'score'} = $score if ($score);
-    $self->{'aggress'} = $aggress;
-    
-    $self->{'staract'} = 1 if ($staract);
+    $self->{score} = $score if ($score);
+    $self->{aggress} = $aggress;
+
+    $self->{staract} = 1 if ($staract);
 
     if (exists $methtrans{$methdam})
     {
-      $self->{'methdam'} = $methtrans{$methdam};
+      $self->{methdam} = $methtrans{$methdam};
     }
     else
     {
-      $self->{'methdam'} = "indifferent";
+      $self->{methdam} = 'indifferent';
     }
 
     if (exists $methtrans{$methdcm})
     {
-      $self->{'methdcm'} = $methtrans{$methdcm};
+      $self->{methdcm} = $methtrans{$methdcm};
     }
     else
     {
-      $self->{'methdcm'} = "indifferent";
+      $self->{methdcm} = 'indifferent';
     }
-    
+
     if (exists $methtrans{$methcpg})
     {
-      $self->{'methcpg'} = $methtrans{$methcpg};
+      $self->{methcpg} = $methtrans{$methcpg};
     }
     else
     {
-      $self->{'methcpg'} = "indifferent";
+      $self->{methcpg} = 'indifferent';
     }
 
     if ($vendors)
@@ -262,16 +262,16 @@ sub new
         $vhsh{$v} = $RE_vendors{$v} if (exists $RE_vendors{$v});
         carp("$v not in vendor list!") unless (exists $RE_vendors{$v});
       }
-      $self->{'vendors'} = \%vhsh;
+      $self->{vendors} = \%vhsh;
     }
-    
-    $self->{'buffers'} = $buffers if ($buffers);
+
+    $self->{buffers} = $buffers if ($buffers);
   }
-  
-  $self->{'start'} = $start if ($start);
-  
-  $self->{'exclude'} = $exclude if ($exclude);
-  
+
+  $self->{start} = $start if ($start);
+
+  $self->{exclude} = $exclude if ($exclude);
+
   return $self;
 }
 
@@ -292,20 +292,9 @@ sub clone
 {
    my ($self) = @_;
    my $copy;
-   foreach my $key (keys %$self)
+   foreach my $key (keys %{$self})
    {
-     if (ref $self->{$key} eq "ARRAY")
-     {
-       $copy->{$key} = [@{$self->{$key}}];
-     }
-     elsif (ref $self->{$key} eq "HASH")
-     {
-       $copy->{$key} = {%{$self->{$key}}};
-     }
-     else
-     {
-      $copy->{$key} = $self->{$key};
-     }
+    $copy->{$key} = $self->{$key};
    }
    bless $copy, ref $self;
    return $copy;
@@ -316,7 +305,7 @@ sub clone
 Generates a hash describing the positions of the enzyme's recognition
 sites in a nucleotide sequence. Keys are offset in nucleotides, and values are
 the recognition site found at said offset as a string.
-  
+
 =cut
 
 sub positions
@@ -491,25 +480,25 @@ Returns the number of units needed to cleave some sequence
 sub units
 {
   my ($self, @args) = @_;
-  
+
   my ($buffer, $sequence) = $self->_rearrange([qw(buffer sequence)], @args);
-  
-  
+
+
   my $poshsh = $self->positions($sequence);
   my $count = scalar keys %{$poshsh};
-  
+
   my $freq = $count / (length $sequence);
-  
+
   my $aggr = $self->aggress() || .000001;
   $aggr = 1 / $aggr;
-  
+
   $buffer = $buffer || $self->acceptable_buffer($self, 100);
   my $buff = $self->buffers->{$buffer} || 1;
   my $jad = $buff / 100;
   my $adj = $jad > 0  ? 1 / $jad : 0;
-  
+
   my $units = sprintf("%.1f", $freq * $aggr * $adj);
-  
+
   return $units;
 }
 
@@ -522,7 +511,7 @@ sub units
              a flag indicating whether or not the sequences in the array are
               required (1 means they must NOT match; default 0 means they must
               match)
-  
+
   Returns : 1 if the enzyme passes;
             0 if the enzyme fails.
 
@@ -538,7 +527,7 @@ sub filter_by_sequence
     my $regex = _regres($seq, 1);
     if ($regex =~ /\[ X \]/x)
     {
-      print "\tWARNING: Can't parse sequence $seq containing non-nucleotide "
+      print "\tWARNING: Cannot parse sequence $seq containing non-nucleotide "
         . "characters - ignoring.\n";
       next;
     }
@@ -583,7 +572,7 @@ sub filter_by_vendor
   {
     unless (exists($RE_vendors{$vend}))
     {
-      print "\tWARNING: Can't parse vendor argument $vend - ignoring.\n";
+      print "\tWARNING: Cannot parse vendor argument $vend - ignoring.\n";
       next;
     }
     $flag++ if ( exists( $self->{vendors}->{$vend} ) );
@@ -596,7 +585,7 @@ sub filter_by_vendor
 
   Arguments : a hashref of buffer thresholds; the key is the buffer name, the
                 value is an activity threshold.
-                
+
   Returns   : 1 if the enzyme meets all the buffer requirements,
               0 else.
 
@@ -612,7 +601,7 @@ sub filter_by_buffer_activity
     my $val = $hshref->{$buff};
     $result = 0 if ( ! exists($rebuff->{$buff}) || $rebuff->{$buff} < $val );
   }
-  
+
   return $result;
 }
 
@@ -620,10 +609,10 @@ sub filter_by_buffer_activity
 
   Arguments : an arrayref of sensitivity values; the key is the sensitivity
                 blocked, inhibited, or indifferent
-              
+
   Returns   : 1 if the enzyme meets the dcm sensitivity requirements,
               0 else.
-            
+
 =cut
 
 sub filter_by_dcm_sensitivity
@@ -636,7 +625,7 @@ sub filter_by_dcm_sensitivity
     if ($sense ne "blocked" && $sense ne "inhibited" && $sense ne "indifferent")
     {
       $sense = lc $sense;
-      print "\tWARNING: Can't parse dcmsense argument $sense - ignoring.\n";
+      print "\tWARNING: Cannot parse dcmsense argument $sense - ignoring.\n";
       next;
     }
     $sensehsh{$sense}++;
@@ -649,10 +638,10 @@ sub filter_by_dcm_sensitivity
 
   Arguments : an arrayref of sensitivity values; the key is the sensitivity
                 blocked, inhibited, or indifferent
-              
+
   Returns   : 1 if the enzyme meets the dam sensitivity requirements,
               0 else.
-            
+
 =cut
 
 sub filter_by_dam_sensitivity
@@ -665,7 +654,7 @@ sub filter_by_dam_sensitivity
     if ($sense ne "blocked" && $sense ne "inhibited" && $sense ne "indifferent")
     {
       $sense = lc $sense;
-      print "\tWARNING: Can't parse damsense argument $sense - ignoring.\n";
+      print "\tWARNING: Cannot parse damsense argument $sense - ignoring.\n";
       next;
     }
     $sensehsh{$sense}++;
@@ -678,10 +667,10 @@ sub filter_by_dam_sensitivity
 
   Arguments : an arrayref of sensitivity values; the key is the sensitivity
                 blocked, inhibited, or indifferent
-              
+
   Returns   : 1 if the enzyme meets the cpg sensitivity requirements,
               0 else.
-            
+
 =cut
 
 sub filter_by_cpg_sensitivity
@@ -694,7 +683,7 @@ sub filter_by_cpg_sensitivity
     if ($sense ne "blocked" && $sense ne "inhibited" && $sense ne "indifferent")
     {
       $sense = lc $sense;
-      print "\tWARNING: Can't parse cpgsense argument $sense - ignoring.\n";
+      print "\tWARNING: Cannot parse cpgsense argument $sense - ignoring.\n";
       next;
     }
     $sensehsh{$sense}++;
@@ -706,7 +695,7 @@ sub filter_by_cpg_sensitivity
 =head2 filter_by_star_activity
 
   Arguments : 1 if star activity required, 0 else
-            
+
   Returns   : 1 if the enzyme meets the star activity requirements,
               0 else.
 
@@ -724,7 +713,7 @@ sub filter_by_star_activity
 =head2 filter_by_incubation_temperature
 
   Arguments : an arrayref of acceptable integer incubation temperatures
-          
+
   Returns   : 1 if the enzyme meets the incubation temperature requirements,
               0 else.
 
@@ -739,7 +728,7 @@ sub filter_by_incubation_temperature
   {
     if ($temp !~ /\d/x || $temp <= 0)
     {
-      print "\tWARNING: Can't parse incubation argument $temp - ignoring.\n";
+      print "\tWARNING: Cannot parse incubation argument $temp - ignoring.\n";
     }
     $temps{$temp}++;
   }
@@ -750,7 +739,7 @@ sub filter_by_incubation_temperature
 =head2 filter_by_inactivation_temperature
 
   Arguments : an acceptable integer inactivation temperature maximum
-          
+
   Returns   : 1 if the enzyme meets the inactivation temperature requirement,
               0 else.
 
@@ -762,7 +751,7 @@ sub filter_by_inactivation_temperature
   my $result = 1;
   if ($temp !~ /\d/x || $temp <= 0)
   {
-    print "\tWARNING: Can't parse inactivation argument $temp - ignoring.\n";
+    print "\tWARNING: Cannot parse inactivation argument $temp - ignoring.\n";
   }
   else
   {
@@ -775,7 +764,7 @@ sub filter_by_inactivation_temperature
 
   Arguments : "nonNonly" if any non N bases are allowed; "ATCGonly" if only
                 A, T, C, or G are allowed
-        
+
   Returns   : 1 if the enzyme meets the ambiguous nucleotide requirement,
               0 else.
 
@@ -787,7 +776,7 @@ sub filter_by_base_ambiguity
   my $result = 1;
   if ($ambig ne "nonNonly" && $ambig ne "ATCGonly")
   {
-    print "\tWARNING: Can't parse ambiguity argument $ambig - ignoring.\n";
+    print "\tWARNING: Cannot parse ambiguity argument $ambig - ignoring.\n";
   }
   else
   {
@@ -802,7 +791,7 @@ sub filter_by_base_ambiguity
 =head2 filter_by_length
 
   Arguments : an arrayref of acceptable recognition site lengths
-        
+
   Returns   : 1 if the enzyme meets the recognition site length requirements,
               0 else.
 
@@ -817,7 +806,7 @@ sub filter_by_length
   {
     if ($len =~ /\D/x || $len <= 0)
     {
-      print "\tWARNING: Can't parse length argument $len - ignoring.\n";
+      print "\tWARNING: Cannot parse length argument $len - ignoring.\n";
       next;
     }
     $lens{$len}++;
@@ -832,7 +821,7 @@ sub filter_by_length
                 pal (palindromic),
                 nonpal (nonpalindromic),
                 pnon (potentially nonpalindromic)
-      
+
   Returns   : 1 if the enzyme meets the palindromy requirements,
               0 else.
 
@@ -847,7 +836,7 @@ sub filter_by_overhang_palindromy
   {
     if ($pal ne "pal" && $pal ne "pnon" && $pal ne "nonpal")
     {
-      print "\tWARNING: Can't parse palindromy argument $pal - ignoring.\n";
+      print "\tWARNING: Cannot parse palindromy argument $pal - ignoring.\n";
       next;
     }
     $pals{$pal}++;
@@ -863,7 +852,7 @@ sub filter_by_overhang_palindromy
                 5 (five prime overhang),
                 3 (three prime overhang),
                 b (blunt ended)
-    
+
   Returns   : 1 if the enzyme meets the overhang requirements,
               0 else.
 
@@ -878,7 +867,7 @@ sub filter_by_stickiness
   {
     if ($stick ne "5" && $stick ne "3" && $stick ne "1" && $stick ne "b")
     {
-      print "\tWARNING: Can't parse sticky argument $stick - ignoring.\n";
+      print "\tWARNING: Cannot parse sticky argument $stick - ignoring.\n";
       next;
     }
     $sticks{$stick}++;
@@ -903,7 +892,7 @@ The name of the enzyme.
 sub id
 {
   my ($self) = @_;
-  return $self->{'id'};
+  return $self->{id};
 }
 
 =head2 display_name
@@ -915,7 +904,7 @@ The name of the enzyme.
 sub display_name
 {
   my ($self) = @_;
-  return $self->{'id'};
+  return $self->{id};
 }
 
 =head2 score
@@ -930,9 +919,9 @@ sub score
   my ($self, $value) = @_;
   if (defined $value)
   {
-    $self->{'score'} = $value;
+    $self->{score} = $value;
   }
-  return $self->{'score'};
+  return $self->{score};
 }
 
 =head2 aggress
@@ -950,9 +939,9 @@ sub aggress
   my ($self, $value) = @_;
   if (defined $value)
   {
-    $self->{'aggress'} = $value;
+    $self->{aggress} = $value;
   }
-  return $self->{'aggress'};
+  return $self->{aggress};
 }
 
 =head2 len
@@ -964,7 +953,7 @@ The length in bases of the recognition sequence (recseq).
 sub len
 {
   my ($self) = @_;
-  return $self->{'length'};
+  return $self->{length};
 }
 
 =head2 methcpg
@@ -976,7 +965,7 @@ The effect of CpG methylation on the enzyme's efficacy.
 sub methcpg
 {
   my ($self) = @_;
-  return $self->{'methcpg'};
+  return $self->{methcpg};
 }
 
 =head2 methdcm
@@ -988,7 +977,7 @@ The effect of Dcm methylation on the enzyme's efficacy.
 sub methdcm
 {
   my ($self) = @_;
-  return $self->{'methdcm'};
+  return $self->{methdcm};
 }
 
 =head2 methdam
@@ -1000,7 +989,7 @@ The effect of Dam methylation on the enzyme's efficacy.
 sub methdam
 {
   my ($self) = @_;
-  return $self->{'methdam'};
+  return $self->{methdam};
 }
 
 =head2 buffers
@@ -1014,7 +1003,7 @@ GeneDesign list are NEB enzymes, this is usually full of NEB buffers.
 sub buffers
 {
   my ($self) = @_;
-  return $self->{'buffers'};
+  return $self->{buffers};
 }
 
 =head2 vendors
@@ -1039,13 +1028,13 @@ of vendors that stock the enzyme. These are read in from the enzyme file.
                       V = Vivantis
                       X = EURx
                       Y = CinnaGen
-                      
+
 =cut
 
 sub vendors
 {
   my ($self) = @_;
-  return $self->{'vendors'};
+  return $self->{vendors};
 }
 
 =head2 tempin
@@ -1057,7 +1046,7 @@ The temperature in degrees Celsius that deactivates the enzyme.
 sub tempin
 {
   my ($self) = @_;
-  return $self->{'tempin'};
+  return $self->{tempin};
 }
 
 =head2 timein
@@ -1069,7 +1058,7 @@ The time required at inactivation temperature to deactivate the enzyme.
 sub timein
 {
   my ($self) = @_;
-  return $self->{'timein'};
+  return $self->{timein};
 }
 
 =head2 temp
@@ -1081,7 +1070,7 @@ Incubation temperature for the best enzyme activity, in degrees Celsius.
 sub temp
 {
   my ($self) = @_;
-  return $self->{'temp'};
+  return $self->{temp};
 }
 
 =head2 recseq
@@ -1096,7 +1085,7 @@ instantiation.
 sub recseq
 {
   my ($self) = @_;
-  return $self->{'recseq'};
+  return $self->{recseq};
 }
 
 =head2 seq
@@ -1108,7 +1097,7 @@ Synonym for recseq
 sub seq
 {
   my ($self) = @_;
-  return $self->{'recseq'};
+  return $self->{recseq};
 }
 
 =head2 cutseq
@@ -1122,7 +1111,7 @@ See http://rebase.neb.com/rebase/rebrec.html for help interpreting this field.
 sub cutseq
 {
   my ($self) = @_;
-  return $self->{'cutseq'};
+  return $self->{cutseq};
 }
 
 =head2 regex
@@ -1140,7 +1129,7 @@ This attribute is defined at instantiation.
 sub regex
 {
   my ($self) = @_;
-  return $self->{'regex'};
+  return $self->{regex};
 }
 
 =head2 class
@@ -1154,10 +1143,10 @@ classes.
   IIP : This enzyme has a symmetric target and a symmetric cleavage site; this
         usually means that the enzyme cleaves inside its own recognition site.
         This is not the same as overhang palindromy!
-        
+
   IIA : This enzyme has an asymmetric recognition site and usually cleaves
         outside of it.
-        
+
   IIB : This enzyme has one recognition site and two cleavage sites, one on
         either side of the recognition site, and thus cuts itself out of
         sequence.
@@ -1167,7 +1156,7 @@ classes.
 sub class
 {
   my ($self) = @_;
-  return $self->{'class'};
+  return $self->{class};
 }
 
 =head2 classex
@@ -1177,7 +1166,7 @@ sub class
 sub classex
 {
   my ($self) = @_;
-  return $self->{'classex'};
+  return $self->{classex};
 }
 
 =head2 class_regexes
@@ -1188,7 +1177,7 @@ Short cut to accessing class regular expressions
 
 sub class_regexes
 {
-  return {"IIP" => $IIPreg, "IIA" => $IIAreg, "IIB" => $IIBreg};
+  return {'IIP' => $IIPreg, 'IIA' => $IIAreg, 'IIB' => $IIBreg};
 }
 
 =head2 type
@@ -1204,7 +1193,7 @@ or b for blunt ends.
 sub type
 {
   my ($self) = @_;
-  return $self->{'type'};
+  return $self->{type};
 }
 
 
@@ -1218,7 +1207,7 @@ returns 1 if an enzyme leaves a 1bp overhang and 0 else.
 sub onebpoverhang
 {
   my ($self) = @_;
-  return $self->{'onebpoverhang'};
+  return $self->{onebpoverhang};
 }
 
 =head2 exclude
@@ -1239,9 +1228,9 @@ sub exclude
   {
     $self->throw("$value is not a reference to an array")
       unless (ref $value eq "ARRAY");
-    $self->{'exclude'} = $value;
+    $self->{exclude} = $value;
   }
-  return $self->{'exclude'};
+  return $self->{exclude};
 }
 
 =head2 palindromy
@@ -1253,13 +1242,13 @@ Information about the overhang the enzyme leaves.
   pnon    = potentially nonpalindromic, or sometimes palindromic and sometimes
             nonpalindromic
   unknown = unknown
-  
+
 =cut
 
 sub palindromy
 {
   my ($self) = @_;
-  return $self->{'palindromy'};
+  return $self->{palindromy};
 }
 
 =head2 staract
@@ -1271,7 +1260,7 @@ sub palindromy
 sub staract
 {
   my ($self) = @_;
-  return $self->{'staract'};
+  return $self->{staract};
 }
 
 =head2 start
@@ -1285,9 +1274,9 @@ sub start
   my ($self, $value) = @_;
   if (defined $value)
   {
-    $self->{'start'} = $value;
+    $self->{start} = $value;
   }
-    return $self->{'start'};
+    return $self->{start};
 }
 
 =head2 outside_cut
@@ -1297,7 +1286,7 @@ sub start
 sub outside_cut
 {
   my ($self) = @_;
-  return $self->{'outside_cut'};
+  return $self->{outside_cut};
 }
 
 =head2 inside_cut
@@ -1307,7 +1296,7 @@ sub outside_cut
 sub inside_cut
 {
   my ($self) = @_;
-  return $self->{'inside_cut'};
+  return $self->{inside_cut};
 }
 
 1;
@@ -1316,7 +1305,7 @@ __END__
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014, GeneDesign developers
+Copyright (c) 2015, GeneDesign developers
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification,
